# Welcome to MDTerp


[![image](https://img.shields.io/pypi/v/MDTerp.svg)](https://pypi.python.org/pypi/MDTerp)
![MDTerp](MDTerp_logo.png)

**A python project for interpreting molecular dynamics (MD) trajectory metastable state classifications from machine-learning models**


-   Free software: MIT License
-   Documentation: <https://shams-mehdi.github.io/MDTerp>
    

## Features

-   Scans blackbox AI classifier models trained on MD data for feature importance.

## Demos

-   [Notebook 1](docs/examples/MDTerp_demo1.ipynb)
-   [Notebook 2](docs/examples/MDTerp_demo2.ipynb)
